.. soundexample:

An example with sound
------------------------

An example of using MoviePy to assemble movie clips with sounds. Here are two scenes of Charade put together:

.. raw:: html

        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; margin-left: 5%;"><iframe type="text/html" src="https://www.youtube.com/embed/gtyFuIoH7W0" frameborder="0" style="position: absolute; top: 0; bottom: 10; width: 90%; height: 100%;" allowfullscreen></iframe></div>

Here is the code:

.. literalinclude:: ../../examples/example_with_sound.py
